from fastapi import Query
from pydantic import BaseModel, EmailStr
from typing import Optional


class RegisterSchema(BaseModel):
    full_name: str
    email: EmailStr
    password: str
    gender: int = Query(None, ge=1, le=3)
    mobile: str = Query(None, min_length=8, max_length=13)
    user_image: Optional[str] = None
    user_type: int = Query(None, ge=1, le=2)
    lang_type: int = Query(None, ge=1, le=2)
    device_type: int = Query(None, ge=1, le=2)
    device_id: str


class LoginSchema(BaseModel):
    email: EmailStr
    password: str
    user_type: int = Query(None, ge=1, le=2)
    lang_type: int = Query(None, ge=1, le=2)
    device_id: str


class OTPSchema(BaseModel):
    access_key: str
    otp: int = Query(None, ge=6, le=6)
